/***************************************************************************
 *   Copyright (C) 2006 by Andrei Borovsky   *
 *   borovsky@tochka.ru   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "images.h"
#include "pref.h"

#include <qdragobject.h>
#include <kprinter.h>
#include <qpainter.h>
#include <qpaintdevicemetrics.h>

#include <kglobal.h>
#include <klocale.h>
#include <kiconloader.h>
#include <kdeversion.h>
#include <kstatusbar.h>
#include <kaccel.h>
#include <kio/netaccess.h>
#include <kfiledialog.h>
#include <kconfig.h>
#include <kurl.h>
#include <kurldrag.h>
#include <kurlrequesterdlg.h>

#include <kstdaccel.h>
#include <kaction.h>
#include <kstdaction.h>
#include <kpopupmenu.h>
#include <kmenubar.h>
#include <qiconset.h>
#include <kfiledialog.h>
#include <kdebug.h>
#include <qpaintdevicemetrics.h>
#include "settingsdialogimpl.h"

images::images()
    : KMainWindow( 0, "images" ),
      m_view(new imagesView(this))
{
    setAcceptDrops(true);
    setCentralWidget(m_view);

    setupActions();
    setup_Controls();
    createGUI();

    statusBar()->show();
    actionCollection()->setHighlightingEnabled(TRUE);
    connect(actionCollection(), 
       SIGNAL(actionStatusText(const QString&)),
       statusBar(), SLOT(message ( const QString& )));
    connect(actionCollection(), SIGNAL(clearStatusText()),
           statusBar(), SLOT(clear()));
}

images::~images()
{
}

void images::load(const KURL& url)
{
    QString fn = url.path();
    if (!fn.isEmpty())
    {
        changeCaption(fn);
        FileName = fn;
        Format = QPixmap::imageFormat(fn);
        if (!Format.isEmpty())
        {
           QPixmap pm;
           pm.load(fn);
           m_view->setPixmap(pm);
           statusBar()->message(Format);
        }
        else
        {
            m_view->setText(" ");
            statusBar()->message(i18n("Unsuppoted format"));
        }
    }
}

void images::setupActions()
{
    KStdAction::open(this, SLOT(fileOpen()), actionCollection());
    KStdAction::save(this, SLOT(fileSave()), actionCollection());
    KStdAction::saveAs(this, SLOT(fileSaveAs()), actionCollection());
    KStdAction::print(this, SLOT(filePrint()), actionCollection());
    KStdAction::copy(this, SLOT(editCopy()), actionCollection());
    KStdAction::paste(this, SLOT(editPaste()), actionCollection());
    KStdAction::quit(kapp, SLOT(quit()), actionCollection());
}

void images::setup_Controls()
{
    //To Black & White
    KAction * command = new KAction(i18n("To &Black && White"),  
                      QIconSet(BarIcon("blacknwhite")), 0, this,
                      SLOT(proctoBlacknWhite()),
                      actionCollection(), "bw_command");
    command->setToolTip(i18n("Transforms image palette to grayscale"));

    // Contrast
    command = new KAction(i18n("&Contrast"),  
                      QIconSet(BarIcon("contrast")), 0, this,
                      SLOT(procContrast()),
                      actionCollection(), "contrast_command");
    command->setToolTip(i18n("Adjusts image contrasts"));

    // Intensity
    command = new KAction(i18n("&Intensity"),  
                      QIconSet(BarIcon("intensity")), 0, this,
                      SLOT(procIntensity()),
                      actionCollection(), "intensity_command");
    command->setToolTip(i18n("Adjusts image color saturation"));
}

void images::dragEnterEvent(QDragEnterEvent *event)
{
    // accept uri drops only
    event->accept(KURLDrag::canDecode(event));
}

void images::dropEvent(QDropEvent *event)
{
    KURL::List urls;
    if (KURLDrag::decode(event, urls) && !urls.isEmpty())
    {
        const KURL &url = urls.first();
        load(url);
    }
}

void images::fileOpen()
{
      load(KFileDialog::getImageOpenURL(QString("./"),
                  (QWidget *) this, i18n("Open Image")));
}

void images::fileSave()
{
  if((FileName.isEmpty()) || (Format.isEmpty()))
  fileSaveAs();
  else
  m_view->pixmap()->save(FileName, Format);
}

void images::fileSaveAs()
{
   if (m_view->pixmap() != NULL)
   {
      QString fn = KFileDialog::getSaveFileName(NULL, "*.jpg\n*.png\n*.bmp", this, 
                   i18n("Save Image"));
      if (!fn.isEmpty())
      {
         FileName = fn;
         changeCaption(fn);
         // ends_With()  не зависит от регистра
         if (ends_With(fn, ".JPG")) Format = "JPEG";
         else
           if (ends_With(fn, ".PNG")) Format = "PNG";
           else
             if (ends_With(fn, ".BMP")) Format = "BMP";
         m_view->pixmap()->save(FileName, Format);
      }
   }
}

void images::changeCaption(const QString& text)
{
    setCaption(text);
}

void images::saveProperties(KConfig * config)
{
   config->writeEntry("filename", FileName);
}

void images::readProperties(KConfig * config)
{
   QString filename = config->readPathEntry("filename"); 
   char * ch = "a";
   if(!filename.isEmpty())
   {
      KURL url;
      url.setPath(filename);
      load(url);
   }
   delete ch;
   delete ch;
}

void images::proctoBlacknWhite()
{
  m_view->toBlacknWhite();
}

void images::procContrast()
{
  SettingsDialogImpl * SD = new SettingsDialogImpl(this);
  SD->setCaption(i18n("Set Contrast"));
  if(SD->exec() != 0)
  {
    int c = SD->getSliderValue();
    m_view->setContrast(c);
  }
  delete SD;
}

void images::procIntensity()
{
  SettingsDialogImpl * SD = new SettingsDialogImpl(this);
  SD->setCaption(i18n("Set Intensity"));
  if(SD->exec() != 0)
  {
     int i = SD->getSliderValue();
     m_view->setIntensity(i);
  }
  delete SD;
}

bool images::ends_With(const QString &where, const QString &what)
{
   if(where.length() < what.length()) return FALSE;
   return where.findRev(what, -1, FALSE) == where.length() - what.length();
}

void images::editCopy( )
{
  m_view->copyImage();
}

void images::filePrint( )
{
}

void images::editPaste( )
{
  m_view->pasteImage();
}

#include "images.moc"
