#include "images_part.h"

#include <kinstance.h>
#include <klocale.h>
#include <kaboutdata.h>

#include <qpixmap.h>
#include <kiconloader.h>

extern "C"
{
    /**
     * This function is the 'main' function of this part.  It takes
     * the form 'void *init_lib<library name>()  It always returns a
     * new factory object
     */
    void *init_libimages1()
    {
        return new ImagesFactory;
    }
};

/**
 * We need one static instance of the factory for our C 'main'
 * function
 */
KInstance *ImagesFactory::s_instance = 0L;

ImagesFactory::ImagesFactory()
{
}

ImagesFactory::~ImagesFactory()
{
    if (s_instance)
    {
        delete s_instance->aboutData();
        delete s_instance;
    }

    s_instance = 0;
}

/* QObject *ImagesFactory::create(QObject *parent, const char *name, const char*,
                               const QStringList& )
{
    QObject *obj = new ImagesPart((QWidget*)parent, name);
    emit objectCreated(obj);
    return obj;
}*/
 QObject* ImagesFactory::createObject( QObject* parent, const char* name,
                                   const char* className,
                                   const QStringList &args )
{
    QObject *obj = new ImagesPart((QWidget*)parent, name);
    emit objectCreated(obj);
    return obj;
};

KInstance *ImagesFactory::instance()
{
    if ( !s_instance )
        s_instance = new KInstance( aboutData() );
    return s_instance;
}

KAboutData * ImagesFactory::aboutData()
{
  KAboutData *about = new KAboutData("images", I18N_NOOP("Images"), "0.1");
  return about;
}

ImagesPart::ImagesPart(QWidget *parent, const char *name)
    : KParts::ReadOnlyPart(parent, name)
{
    setInstance(ImagesFactory::instance());

    // create a canvas to insert our widget
    QWidget *canvas = new QWidget(parent);
    canvas->setFocusPolicy(QWidget::ClickFocus);
    setWidget(canvas);

    m_extension = new ImagesBrowserExtension(this);

    actiontoBlacknWhite = new KAction(i18n("To &Black && White"),  
                      QIconSet(BarIcon("blacknwhite")), 0, this,
                      SLOT(proctoBlacknWhite()),
                      actionCollection(), "bw_command");
    actiontoBlacknWhite->setToolTip(i18n("Transforms image palette to grayscale"));
    setXMLFile("images_part.rc");

    widget = new imagesView(canvas);
    widget->show();
}

ImagesPart::~ImagesPart()
{
    closeURL();
}

bool ImagesPart::openFile()
{
    QPixmap pm(m_file);
    widget->setPixmap(pm);
    widget->setAutoResize(true);
    return !pm.isNull();
}

bool ImagesPart::closeURL()
{
    return true;
}

void ImagesPart::proctoBlacknWhite()
{
   widget->toBlacknWhite();
}

ImagesBrowserExtension::ImagesBrowserExtension(ImagesPart *parent)
    : KParts::BrowserExtension(parent, "ImagesBrowserExtension")
{
}

ImagesBrowserExtension::~ImagesBrowserExtension()
{
}
