

/***************************************************************************
 *   Copyright (C) 2006 by Andrei Borovsky  *
 *   borovsky@tochka.ru  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "imagesview.h"

#include <kapplication.h>
#include <kmainwindow.h>
#include <dcopclient.h>
#include <kdebug.h>
#include <qpainter.h>
#include <qlayout.h>

#include <ktrader.h>
#include <klibloader.h>
#include <kpixmap.h>
#include <kpixmapeffect.h>

#include <qimage.h>
#include <krun.h>
#include <klocale.h>

#include <qclipboard.h>

#define ADD_PID

imagesView::imagesView(QWidget *parent)
    : QLabel(parent),
      DCOPObject("imagesIface")
{
    DCOPClient * client = kapp->dcopClient();
    client->attach();
    #ifdef ADD_PID
       client->registerAs("images");
    #else
       client->registerAs("images", FALSE);
    #endif
    // setup our layout manager to automatically add our widgets
    setAlignment(Qt::AlignHCenter|Qt::AlignVCenter);
}

imagesView::~imagesView()
{
}


void imagesView::toBlacknWhite()
{
  if (pixmap() == NULL)
  {
    kdDebug() << k_funcinfo << "Trying to modify an empty pixmap" << endl;
    return;
  }

  KPixmap kpm(* pixmap());
  KPixmapEffect::toGray(kpm, FALSE);
  setPixmap(kpm);
}

void imagesView::setContrast(int c)
{
  if (pixmap() == NULL)
  {
    kdDebug() << k_funcinfo << "Trying to modify an empty pixmap" << endl;
    return;
  }

  KPixmap kpm(* pixmap());
  KPixmapEffect::contrast(kpm, (c - 50)*5);
  setPixmap(kpm);
}

void imagesView::setIntensity(int i)
{

  if (pixmap() == NULL)
  {
    kdDebug() << k_funcinfo << "Trying to modify an empty pixmap" << endl;
    return;
  }

  KPixmap kpm(* pixmap());
  KPixmapEffect::intensity(kpm, (i-50)/10);
  setPixmap(kpm);
}

void imagesView::show_Image(const QPixmap data)
{
   setPixmap(KPixmap(data));
}

void imagesView::copyImage( )
{
  if (pixmap() == NULL)
  {
    kdDebug() << k_funcinfo << "Trying to copy an empty pixmap" << endl;
    return;
  }

  kapp->clipboard()->setPixmap(*pixmap());
}

void imagesView::pasteImage( )
{
    QPixmap pixmap = kapp->clipboard()->pixmap();
    if (!pixmap.isNull())
      setPixmap(pixmap);
}

QPixmap * imagesView::getPixmap( )
{
   return pixmap();
}

#include "imagesview.moc"
